@@ -1,7 +1,7 @@
 package Rope;
 
 use 5.006; use strict; use warnings;
-our $VERSION = '0.28';
+our $VERSION = '0.29';
 use Rope::Object;
 my (%META, %PRO);
 our @ISA;
@@ -15,6 +15,7 @@ BEGIN {
 		},
 		scope => sub {
 			my ($caller, $self, %props) = @_;
+			delete $props{properties}{$_} for qw/INITIALISE INITIALISED/;
 			for my $prop (keys %{$props{properties}}) {
 				if ($props{properties}{$prop}{value} && ref $props{properties}{$prop}{value} eq 'CODE') {
 					my $cb = $props{properties}{$prop}{value};
@@ -392,11 +393,15 @@ BEGIN {
 						$build->{properties}->{$_}->{value} = ref $builder ? $builder->($build) : $caller->$builder($build);
 					}
 				}
-				$self->INITIALISE($build) if $self->can('INITIALISE');
+				exists $build->{properties}->{INITIALISE} 
+					? $build->{properties}->{INITIALISE}->{value}->($self, $build)
+					: $self->can('INITIALISE') && $self->INITIALISE($build);
 				tie %{${$self}->{prototype}}, 'Rope::Object', $PRO{scope}($caller, $self, %{$build});
 				$META{initialised}{$caller}->{${$self}->{identifier}} = $self;
 				$self->{ROPE_init}->();
-				$self->INITIALISED() if $self->can('INITIALISED');
+				exists $build->{properties}->{INITIALISED} 
+					? $build->{properties}->{INITIALISED}->{value}->($self, $build)
+					: $self->can('INITIALISED') && $self->INITIALISED($build); 
 				return $self;
 			};
 		}
@@ -606,7 +611,7 @@ Rope - Tied objects
 
 =head1 VERSION
 
-Version 0.28
+Version 0.29
 
 =cut
 
